import type { PublicProps, ComponentPublicInstance, Slot } from "vue";
import * as cheetahGrid from 'cheetah-grid'
export { cheetahGrid }
export function storeElement (vm: ComponentPublicInstance): void;
export function removeElement (vm: ComponentPublicInstance): void;
export function getComponentFromElement (element: HTMLElement): ComponentPublicInstance | undefined;

type ComponentConstructor<Props = {}, Properties = {}, Slots = {}> = {
  new (): {
    $props: PublicProps & Props
    $slots: Slots
  } & Properties
}

/** Defines the Grid. */
export const CGrid: ComponentConstructor<
  {
        /** Defines a records or data source. */
    data?: any[]|object;
    /** Defines a frozen col Count */
    frozenColCount?: number|string;
    /** Defines the header row height(s) */
    headerRowHeight?: number|any[];
    /** Allow pasting of range. */
    allowRangePaste?: boolean;
    /** Trim the pasted text on pasting. */
    trimOnPaste?: boolean;
    /** Default grid row height. */
    defaultRowHeight?: number;
    /** Default grid col width. */
    defaultColWidth?: number;
    /** Defines a records filter */
    filter?: Function;
    /** Default font. */
    font?: string;
    /** Underlay background color. */
    underlayBackgroundColor?: string;
    /** Defines the grid theme */
    theme?: object|string;
    /** Specify `true` to enable cell movement by Tab key. You can also specify a function that determines which cell to move to. */
    moveCellOnTabKey?: boolean|Function;
    /** Specify `true` to enable cell movement by Enter key. You can also specify a function that determines which cell to move to. */
    moveCellOnEnterKey?: boolean|Function;
    /** Specify `true` to enable enable deletion of cell values with the Del and BS keys. */
    deleteCellValueOnDelKey?: boolean;
    /** Specify `true` to enable select all cells by Ctrl + A key. */
    selectAllOnCtrlAKey?: boolean;
    /** Specify `true` to disable column resizing */
    disableColumnResize?: boolean;
    /** Defines disabled */
    disabled?: boolean;
    /** Defines readonly */
    readonly?: boolean;
    /** Defines a raw options for Cheetah Grid */
    options?: object;
    onClickCell?: Function;
    onDblclickCell?: Function;
    onDbltapCell?: Function;
    onMousedownCell?: Function;
    onMouseupCell?: Function;
    onSelectedCell?: Function;
    onKeydown?: Function;
    onMousemoveCell?: Function;
    onMouseenterCell?: Function;
    onMouseleaveCell?: Function;
    onMouseoverCell?: Function;
    onMouseoutCell?: Function;
    onTouchstartCell?: Function;
    onContextmenuCell?: Function;
    onInputCell?: Function;
    onPasteCell?: Function;
    onDeleteCell?: Function;
    onEditableinputCell?: Function;
    onModifyStatusEditableinputCell?: Function;
    onResizeColumn?: Function;
    onScroll?: Function;
    onFocusGrid?: Function;
    onBlurGrid?: Function;
    onBeforeChangeValue?: Function;
    onChangedValue?: Function;
    onChangedHeaderValue?: Function;
    onRejectedPasteValues?: Function;
  },
  {
        /** Redraws the whole grid. */
    invalidate: () => void;
    /** Apply the changed size. */
    updateSize: () => void;
    /** Apply the changed scroll size. */
    updateScroll: () => void;
    rawGrid: cheetahGrid.ListGrid<unknown>;
  },
  {
        /** Use this slot to set the simple header definition.
              The definition is set to `header` property described in [Define Headers and Columns](https://future-architect.github.io/cheetah-grid/documents/api/js/headers_columns.html) */
    "default"?: Slot<{} | undefined>;
    /** Use this slot to set the layout header definition.
              Use this slot in combination with the `layout-body` slot.
              The definition is set to `layout.header` property described in [Advanced Layout](https://future-architect.github.io/cheetah-grid/documents/api/vue/advanced_layout/). */
    "layout-header"?: Slot<{} | undefined>;
    /** Use this slot to set the layout body definition.
              Use this slot in combination with the `layout-header` slot.
              The definition is set to `layout.body` property described in [Advanced Layout](https://future-architect.github.io/cheetah-grid/documents/api/vue/advanced_layout/). */
    "layout-body"?: Slot<{} | undefined>;
  }
>;
/** Defines branch graph column. */
export const CGridBranchGraphColumn: ComponentConstructor<
  {
        /** Defines a column data field */
    field?: object|string|Function;
    /** Defines a default column width */
    width?: number|string;
    /** Defines a column min width */
    minWidth?: number|string;
    /** Defines a column max width */
    maxWidth?: number|string;
    /** Defines a column style. Same as [the `style` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_styles/). */
    columnStyle?: object|string|Function;
    /** Defines an action */
    action?: object|string|Function;
    /** Defines a header caption */
    caption?: string|Function;
    /** Enable cache */
    cache?: boolean;
    /** Defines the layout colspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    colspan?: number|string;
    /** Defines a vue filter name */
    filter?: string|Function;
    /** Defines a column header action.  Same as [the `headerAction` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_actions.html). */
    headerAction?: object|string|Function;
    /** Defines a column header data field */
    headerField?: string;
    /** Defines a header icon */
    headerIcon?: object|string;
    /** Defines a column header style. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerStyle?: object|string|Function;
    /** Defines a column header type. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerType?: object|string|Function;
    /** Defines an icon. Same as [the `icon` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_icon.html). */
    icon?: object|string|Function;
    /** Defines a message generation method. Same as [the `message` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/cell_message.html). */
    message?: object|string|Function;
    /** Defines the layout rowspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    rowspan?: number|string;
    /** Defines a sort. See "[Sort by Column](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/column_sort.html)" for detail. */
    sort?: boolean|string|Function;
    /** Defines a start type */
    start?: string;
    onClickCell?: Function;
    onDblclickCell?: Function;
    onDbltapCell?: Function;
    onMousedownCell?: Function;
    onMouseupCell?: Function;
    onSelectedCell?: Function;
    onKeydown?: Function;
    onMousemoveCell?: Function;
    onMouseenterCell?: Function;
    onMouseleaveCell?: Function;
    onMouseoverCell?: Function;
    onMouseoutCell?: Function;
    onTouchstartCell?: Function;
    onContextmenuCell?: Function;
    onInputCell?: Function;
    onPasteCell?: Function;
    onDeleteCell?: Function;
    onEditableinputCell?: Function;
    onModifyStatusEditableinputCell?: Function;
    onResizeColumn?: Function;
    onScroll?: Function;
    onFocusGrid?: Function;
    onBlurGrid?: Function;
    onBeforeChangeValue?: Function;
    onChangedValue?: Function;
    onChangedHeaderValue?: Function;
    onRejectedPasteValues?: Function;
  },
  {
        /** Redraws the whole grid. */
    invalidate: () => void;
  },
  {
        /** Use this slot to set the header caption */
    "default"?: Slot<{} | undefined>;
  }
>;
/** Defines button column. */
export const CGridButtonColumn: ComponentConstructor<
  {
        /** Defines a column data field */
    field?: object|string|Function;
    /** Defines a default column width */
    width?: number|string;
    /** Defines a column min width */
    minWidth?: number|string;
    /** Defines a column max width */
    maxWidth?: number|string;
    /** Defines a column style. Same as [the `style` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_styles/). */
    columnStyle?: object|string|Function;
    /** Defines a button caption */
    caption?: string;
    /** Defines disabled. You can also control each record by specifying a function. */
    disabled?: boolean|Function;
    /** Defines the layout colspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    colspan?: number|string;
    /** Defines a vue filter name */
    filter?: string|Function;
    /** Defines a column header action.  Same as [the `headerAction` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_actions.html). */
    headerAction?: object|string|Function;
    /** Defines a column header data field */
    headerField?: string;
    /** Defines a header icon */
    headerIcon?: object|string;
    /** Defines a column header style. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerStyle?: object|string|Function;
    /** Defines a column header type. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerType?: object|string|Function;
    /** Defines an icon. Same as [the `icon` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_icon.html). */
    icon?: object|string|Function;
    /** Defines a message generation method. Same as [the `message` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/cell_message.html). */
    message?: object|string|Function;
    /** Defines the layout rowspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    rowspan?: number|string;
    /** Defines a sort. See "[Sort by Column](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/column_sort.html)" for detail. */
    sort?: boolean|string|Function;
    onClickCell?: Function;
    onDblclickCell?: Function;
    onDbltapCell?: Function;
    onMousedownCell?: Function;
    onMouseupCell?: Function;
    onSelectedCell?: Function;
    onKeydown?: Function;
    onMousemoveCell?: Function;
    onMouseenterCell?: Function;
    onMouseleaveCell?: Function;
    onMouseoverCell?: Function;
    onMouseoutCell?: Function;
    onTouchstartCell?: Function;
    onContextmenuCell?: Function;
    onInputCell?: Function;
    onPasteCell?: Function;
    onDeleteCell?: Function;
    onEditableinputCell?: Function;
    onModifyStatusEditableinputCell?: Function;
    onResizeColumn?: Function;
    onScroll?: Function;
    onFocusGrid?: Function;
    onBlurGrid?: Function;
    onBeforeChangeValue?: Function;
    onChangedValue?: Function;
    onChangedHeaderValue?: Function;
    onRejectedPasteValues?: Function;
  },
  {
        /** Redraws the whole grid. */
    invalidate: () => void;
  },
  {
        /** Use this slot to set the header caption */
    "default"?: Slot<{} | undefined>;
  }
>;
/** Defines checkbox column. */
export const CGridCheckColumn: ComponentConstructor<
  {
        /** Defines a column data field */
    field?: object|string|Function;
    /** Defines a default column width */
    width?: number|string;
    /** Defines a column min width */
    minWidth?: number|string;
    /** Defines a column max width */
    maxWidth?: number|string;
    /** Defines a column style. Same as [the `style` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_styles/). */
    columnStyle?: object|string|Function;
    /** Defines a header caption */
    caption?: string|Function;
    /** Defines disabled. You can also control each record by specifying a function. */
    disabled?: boolean|Function;
    /** Defines readonly. You can also control each record by specifying a function. */
    readonly?: boolean|Function;
    /** Defines the layout colspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    colspan?: number|string;
    /** Defines a vue filter name */
    filter?: string|Function;
    /** Defines a column header action.  Same as [the `headerAction` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_actions.html). */
    headerAction?: object|string|Function;
    /** Defines a column header data field */
    headerField?: string;
    /** Defines a header icon */
    headerIcon?: object|string;
    /** Defines a column header style. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerStyle?: object|string|Function;
    /** Defines a column header type. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerType?: object|string|Function;
    /** Defines an icon. Same as [the `icon` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_icon.html). */
    icon?: object|string|Function;
    /** Defines a message generation method. Same as [the `message` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/cell_message.html). */
    message?: object|string|Function;
    /** Defines the layout rowspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    rowspan?: number|string;
    /** Defines a sort. See "[Sort by Column](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/column_sort.html)" for detail. */
    sort?: boolean|string|Function;
    onClickCell?: Function;
    onDblclickCell?: Function;
    onDbltapCell?: Function;
    onMousedownCell?: Function;
    onMouseupCell?: Function;
    onSelectedCell?: Function;
    onKeydown?: Function;
    onMousemoveCell?: Function;
    onMouseenterCell?: Function;
    onMouseleaveCell?: Function;
    onMouseoverCell?: Function;
    onMouseoutCell?: Function;
    onTouchstartCell?: Function;
    onContextmenuCell?: Function;
    onInputCell?: Function;
    onPasteCell?: Function;
    onDeleteCell?: Function;
    onEditableinputCell?: Function;
    onModifyStatusEditableinputCell?: Function;
    onResizeColumn?: Function;
    onScroll?: Function;
    onFocusGrid?: Function;
    onBlurGrid?: Function;
    onBeforeChangeValue?: Function;
    onChangedValue?: Function;
    onChangedHeaderValue?: Function;
    onRejectedPasteValues?: Function;
  },
  {
        /** Redraws the whole grid. */
    invalidate: () => void;
  },
  {
        /** Use this slot to set the header caption */
    "default"?: Slot<{} | undefined>;
  }
>;
/** Defines column. */
export const CGridColumn: ComponentConstructor<
  {
        /** Defines a column data field */
    field?: object|string|Function;
    /** Defines a default column width */
    width?: number|string;
    /** Defines a column min width */
    minWidth?: number|string;
    /** Defines a column max width */
    maxWidth?: number|string;
    /** Defines a column type */
    columnType?: object|string|Function;
    /** Defines a column style. Same as [the `style` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_styles/). */
    columnStyle?: object|string|Function;
    /** Defines an action */
    action?: object|string|Function;
    /** Defines a header caption */
    caption?: string|Function;
    /** Defines the layout colspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    colspan?: number|string;
    /** Defines a vue filter name */
    filter?: string|Function;
    /** Defines a column header action.  Same as [the `headerAction` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_actions.html). */
    headerAction?: object|string|Function;
    /** Defines a column header data field */
    headerField?: string;
    /** Defines a header icon */
    headerIcon?: object|string;
    /** Defines a column header style. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerStyle?: object|string|Function;
    /** Defines a column header type. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerType?: object|string|Function;
    /** Defines an icon. Same as [the `icon` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_icon.html). */
    icon?: object|string|Function;
    /** Defines a message generation method. Same as [the `message` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/cell_message.html). */
    message?: object|string|Function;
    /** Defines the layout rowspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    rowspan?: number|string;
    /** Defines a sort. See "[Sort by Column](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/column_sort.html)" for detail. */
    sort?: boolean|string|Function;
    onClickCell?: Function;
    onDblclickCell?: Function;
    onDbltapCell?: Function;
    onMousedownCell?: Function;
    onMouseupCell?: Function;
    onSelectedCell?: Function;
    onKeydown?: Function;
    onMousemoveCell?: Function;
    onMouseenterCell?: Function;
    onMouseleaveCell?: Function;
    onMouseoverCell?: Function;
    onMouseoutCell?: Function;
    onTouchstartCell?: Function;
    onContextmenuCell?: Function;
    onInputCell?: Function;
    onPasteCell?: Function;
    onDeleteCell?: Function;
    onEditableinputCell?: Function;
    onModifyStatusEditableinputCell?: Function;
    onResizeColumn?: Function;
    onScroll?: Function;
    onFocusGrid?: Function;
    onBlurGrid?: Function;
    onBeforeChangeValue?: Function;
    onChangedValue?: Function;
    onChangedHeaderValue?: Function;
    onRejectedPasteValues?: Function;
  },
  {
        /** Redraws the whole grid. */
    invalidate: () => void;
  },
  {
        /** Use this slot to set the header caption */
    "default"?: Slot<{} | undefined>;
  }
>;
/** Defines multiple header.
Can be used in the `default` slot of `CGrid`. */
export const CGridColumnGroup: ComponentConstructor<
  {
        /** Defines a header caption */
    caption?: string|Function;
    /** Defines a column header action.  Same as [the `headerAction` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_actions.html). */
    headerAction?: object|string|Function;
    /** Defines a column header data field */
    headerField?: string;
    /** Defines a header icon */
    headerIcon?: object|string;
    /** Defines a column header style. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerStyle?: object|string|Function;
    /** Defines a column header type. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerType?: object|string|Function;
    /** Defines a sort. See "[Sort by Column](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/column_sort.html)" for detail. */
    sort?: boolean|string|Function;
    onClickCell?: Function;
    onDblclickCell?: Function;
    onDbltapCell?: Function;
    onMousedownCell?: Function;
    onMouseupCell?: Function;
    onSelectedCell?: Function;
    onKeydown?: Function;
    onMousemoveCell?: Function;
    onMouseenterCell?: Function;
    onMouseleaveCell?: Function;
    onMouseoverCell?: Function;
    onMouseoutCell?: Function;
    onTouchstartCell?: Function;
    onContextmenuCell?: Function;
    onInputCell?: Function;
    onPasteCell?: Function;
    onDeleteCell?: Function;
    onEditableinputCell?: Function;
    onModifyStatusEditableinputCell?: Function;
    onResizeColumn?: Function;
    onScroll?: Function;
    onFocusGrid?: Function;
    onBlurGrid?: Function;
    onBeforeChangeValue?: Function;
    onChangedValue?: Function;
    onChangedHeaderValue?: Function;
    onRejectedPasteValues?: Function;
  },
  {
        /** Redraws the whole grid. */
    invalidate: () => void;
  },
  {
        /** Use this slot to set the children columns definition */
    "default"?: Slot<{} | undefined>;
  }
>;
/** Defines layout header.
Can be used in the `layout-header` slot of `CGrid`. */
export const CGridHeader: ComponentConstructor<
  {
        /** Defines a default column width */
    width?: number|string;
    /** Defines a column min width */
    minWidth?: number|string;
    /** Defines a column max width */
    maxWidth?: number|string;
    /** Defines a header caption */
    caption?: string|Function;
    /** Defines the layout colspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    colspan?: number|string;
    /** Defines a column header action.  Same as [the `headerAction` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_actions.html). */
    headerAction?: object|string|Function;
    /** Defines a column header data field */
    headerField?: string;
    /** Defines a header icon */
    headerIcon?: object|string;
    /** Defines a column header style. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerStyle?: object|string|Function;
    /** Defines a column header type. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerType?: object|string|Function;
    /** Defines the layout rowspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    rowspan?: number|string;
    /** Defines a sort. See "[Sort by Column](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/column_sort.html)" for detail. */
    sort?: boolean|string|Function;
    onClickCell?: Function;
    onDblclickCell?: Function;
    onDbltapCell?: Function;
    onMousedownCell?: Function;
    onMouseupCell?: Function;
    onSelectedCell?: Function;
    onKeydown?: Function;
    onMousemoveCell?: Function;
    onMouseenterCell?: Function;
    onMouseleaveCell?: Function;
    onMouseoverCell?: Function;
    onMouseoutCell?: Function;
    onTouchstartCell?: Function;
    onContextmenuCell?: Function;
    onInputCell?: Function;
    onPasteCell?: Function;
    onDeleteCell?: Function;
    onEditableinputCell?: Function;
    onModifyStatusEditableinputCell?: Function;
    onResizeColumn?: Function;
    onScroll?: Function;
    onFocusGrid?: Function;
    onBlurGrid?: Function;
    onBeforeChangeValue?: Function;
    onChangedValue?: Function;
    onChangedHeaderValue?: Function;
    onRejectedPasteValues?: Function;
  },
  {
        /** Redraws the whole grid. */
    invalidate: () => void;
  },
  {
        /** Use this slot to set the header caption */
    "default"?: Slot<{} | undefined>;
  }
>;
/** Defines icon column. */
export const CGridIconColumn: ComponentConstructor<
  {
        /** Defines a column data field */
    field?: object|string|Function;
    /** Defines a default column width */
    width?: number|string;
    /** Defines a column min width */
    minWidth?: number|string;
    /** Defines a column max width */
    maxWidth?: number|string;
    /** Defines a column style. Same as [the `style` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_styles/). */
    columnStyle?: object|string|Function;
    /** Defines an action */
    action?: object|string|Function;
    /** Defines a header caption */
    caption?: string|Function;
    /** Defines the layout colspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    colspan?: number|string;
    /** Defines a vue filter name */
    filter?: string|Function;
    /** Defines a column header action.  Same as [the `headerAction` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_actions.html). */
    headerAction?: object|string|Function;
    /** Defines a column header data field */
    headerField?: string;
    /** Defines a header icon */
    headerIcon?: object|string;
    /** Defines a column header style. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerStyle?: object|string|Function;
    /** Defines a column header type. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerType?: object|string|Function;
    /** Defines an icon. Same as [the `icon` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_icon.html). */
    icon?: object|string|Function;
    /** Defines an icon class name */
    iconClassName?: string|Function;
    /** Defines an icon content */
    iconContent?: string|Function;
    /** Defines an icon name */
    iconName?: string|Function;
    /** Defines an icon tag name */
    iconTagName?: string|Function;
    /** Defines an icon width */
    iconWidth?: number|string|Function;
    /** Defines a message generation method. Same as [the `message` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/cell_message.html). */
    message?: object|string|Function;
    /** Defines the layout rowspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    rowspan?: number|string;
    /** Defines a sort. See "[Sort by Column](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/column_sort.html)" for detail. */
    sort?: boolean|string|Function;
    onClickCell?: Function;
    onDblclickCell?: Function;
    onDbltapCell?: Function;
    onMousedownCell?: Function;
    onMouseupCell?: Function;
    onSelectedCell?: Function;
    onKeydown?: Function;
    onMousemoveCell?: Function;
    onMouseenterCell?: Function;
    onMouseleaveCell?: Function;
    onMouseoverCell?: Function;
    onMouseoutCell?: Function;
    onTouchstartCell?: Function;
    onContextmenuCell?: Function;
    onInputCell?: Function;
    onPasteCell?: Function;
    onDeleteCell?: Function;
    onEditableinputCell?: Function;
    onModifyStatusEditableinputCell?: Function;
    onResizeColumn?: Function;
    onScroll?: Function;
    onFocusGrid?: Function;
    onBlurGrid?: Function;
    onBeforeChangeValue?: Function;
    onChangedValue?: Function;
    onChangedHeaderValue?: Function;
    onRejectedPasteValues?: Function;
  },
  {
        /** Redraws the whole grid. */
    invalidate: () => void;
  },
  {
        /** Use this slot to set the header caption */
    "default"?: Slot<{} | undefined>;
  }
>;
/** Defines input column. */
export const CGridInputColumn: ComponentConstructor<
  {
        /** Defines a column data field */
    field?: object|string|Function;
    /** Defines a default column width */
    width?: number|string;
    /** Defines a column min width */
    minWidth?: number|string;
    /** Defines a column max width */
    maxWidth?: number|string;
    /** Defines a column type */
    columnType?: object|string|Function;
    /** Defines a column style. Same as [the `style` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_styles/). */
    columnStyle?: object|string|Function;
    /** Defines a header caption */
    caption?: string|Function;
    /** Defines disabled. You can also control each record by specifying a function. */
    disabled?: boolean|Function;
    /** Defines readonly. You can also control each record by specifying a function. */
    readonly?: boolean|Function;
    /** Defines the layout colspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    colspan?: number|string;
    /** Defines a vue filter name */
    filter?: string|Function;
    /** Defines a column header action.  Same as [the `headerAction` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_actions.html). */
    headerAction?: object|string|Function;
    /** Defines a column header data field */
    headerField?: string;
    /** Defines a header icon */
    headerIcon?: object|string;
    /** Defines a column header style. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerStyle?: object|string|Function;
    /** Defines a column header type. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerType?: object|string|Function;
    /** Defines a helper text ganarator */
    helperText?: string|Function;
    /** Defines an icon. Same as [the `icon` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_icon.html). */
    icon?: object|string|Function;
    /** Defines an input class name */
    inputClassList?: any[]|string|Function;
    /** Defines an input type */
    inputType?: string|Function;
    /** Defines an input validator */
    inputValidator?: Function;
    /** Defines a message generation method. Same as [the `message` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/cell_message.html). */
    message?: object|string|Function;
    /** Defines the layout rowspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    rowspan?: number|string;
    /** Defines a sort. See "[Sort by Column](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/column_sort.html)" for detail. */
    sort?: boolean|string|Function;
    /** Defines a validator */
    validator?: Function;
    onClickCell?: Function;
    onDblclickCell?: Function;
    onDbltapCell?: Function;
    onMousedownCell?: Function;
    onMouseupCell?: Function;
    onSelectedCell?: Function;
    onKeydown?: Function;
    onMousemoveCell?: Function;
    onMouseenterCell?: Function;
    onMouseleaveCell?: Function;
    onMouseoverCell?: Function;
    onMouseoutCell?: Function;
    onTouchstartCell?: Function;
    onContextmenuCell?: Function;
    onInputCell?: Function;
    onPasteCell?: Function;
    onDeleteCell?: Function;
    onEditableinputCell?: Function;
    onModifyStatusEditableinputCell?: Function;
    onResizeColumn?: Function;
    onScroll?: Function;
    onFocusGrid?: Function;
    onBlurGrid?: Function;
    onBeforeChangeValue?: Function;
    onChangedValue?: Function;
    onChangedHeaderValue?: Function;
    onRejectedPasteValues?: Function;
  },
  {
        /** Redraws the whole grid. */
    invalidate: () => void;
  },
  {
        /** Use this slot to set the header caption */
    "default"?: Slot<{} | undefined>;
  }
>;
/** Defines layout row.
Can be used in the `layout-header` slot and the `layout-body` slot of `CGrid`. */
export const CGridLayoutRow: ComponentConstructor<
  {
        onClickCell?: Function;
    onDblclickCell?: Function;
    onDbltapCell?: Function;
    onMousedownCell?: Function;
    onMouseupCell?: Function;
    onSelectedCell?: Function;
    onKeydown?: Function;
    onMousemoveCell?: Function;
    onMouseenterCell?: Function;
    onMouseleaveCell?: Function;
    onMouseoverCell?: Function;
    onMouseoutCell?: Function;
    onTouchstartCell?: Function;
    onContextmenuCell?: Function;
    onInputCell?: Function;
    onPasteCell?: Function;
    onDeleteCell?: Function;
    onEditableinputCell?: Function;
    onModifyStatusEditableinputCell?: Function;
    onResizeColumn?: Function;
    onScroll?: Function;
    onFocusGrid?: Function;
    onBlurGrid?: Function;
    onBeforeChangeValue?: Function;
    onChangedValue?: Function;
    onChangedHeaderValue?: Function;
    onRejectedPasteValues?: Function;
  },
  {
        
  },
  {
        /** Use this slot to set the row layout definition */
    "default"?: Slot<{} | undefined>;
  }
>;
/** Defines link column. */
export const CGridLinkColumn: ComponentConstructor<
  {
        /** Defines a column data field */
    field?: object|string|Function;
    /** Defines a default column width */
    width?: number|string;
    /** Defines a column min width */
    minWidth?: number|string;
    /** Defines a column max width */
    maxWidth?: number|string;
    /** Defines a column type */
    columnType?: object|string|Function;
    /** Defines a column style. Same as [the `style` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_styles/). */
    columnStyle?: object|string|Function;
    /** Defines a header caption */
    caption?: string|Function;
    /** Defines disabled. You can also control each record by specifying a function. */
    disabled?: boolean|Function;
    /** Defines the layout colspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    colspan?: number|string;
    /** Defines a vue filter name */
    filter?: string|Function;
    /** Defines a column header action.  Same as [the `headerAction` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_actions.html). */
    headerAction?: object|string|Function;
    /** Defines a column header data field */
    headerField?: string;
    /** Defines a header icon */
    headerIcon?: object|string;
    /** Defines a column header style. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerStyle?: object|string|Function;
    /** Defines a column header type. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerType?: object|string|Function;
    /** Defines a href */
    href?: string|Function;
    /** Defines an icon. Same as [the `icon` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_icon.html). */
    icon?: object|string|Function;
    /** Defines a message generation method. Same as [the `message` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/cell_message.html). */
    message?: object|string|Function;
    /** Defines the layout rowspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    rowspan?: number|string;
    /** Defines a sort. See "[Sort by Column](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/column_sort.html)" for detail. */
    sort?: boolean|string|Function;
    /** Defines an anchor target */
    target?: string;
    onClickCell?: Function;
    onDblclickCell?: Function;
    onDbltapCell?: Function;
    onMousedownCell?: Function;
    onMouseupCell?: Function;
    onSelectedCell?: Function;
    onKeydown?: Function;
    onMousemoveCell?: Function;
    onMouseenterCell?: Function;
    onMouseleaveCell?: Function;
    onMouseoverCell?: Function;
    onMouseoutCell?: Function;
    onTouchstartCell?: Function;
    onContextmenuCell?: Function;
    onInputCell?: Function;
    onPasteCell?: Function;
    onDeleteCell?: Function;
    onEditableinputCell?: Function;
    onModifyStatusEditableinputCell?: Function;
    onResizeColumn?: Function;
    onScroll?: Function;
    onFocusGrid?: Function;
    onBlurGrid?: Function;
    onBeforeChangeValue?: Function;
    onChangedValue?: Function;
    onChangedHeaderValue?: Function;
    onRejectedPasteValues?: Function;
  },
  {
        /** Redraws the whole grid. */
    invalidate: () => void;
  },
  {
        /** Use this slot to set the header caption */
    "default"?: Slot<{} | undefined>;
  }
>;
/** Defines select menu column. */
export const CGridMenuColumn: ComponentConstructor<
  {
        /** Defines a column data field */
    field?: object|string|Function;
    /** Defines a default column width */
    width?: number|string;
    /** Defines a column min width */
    minWidth?: number|string;
    /** Defines a column max width */
    maxWidth?: number|string;
    /** Defines a column style. Same as [the `style` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_styles/). */
    columnStyle?: object|string|Function;
    /** Defines a header caption */
    caption?: string|Function;
    /** Defines disabled. You can also control each record by specifying a function. */
    disabled?: boolean|Function;
    /** Defines readonly. You can also control each record by specifying a function. */
    readonly?: boolean|Function;
    /** Defines the layout colspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    colspan?: number|string;
    /** Defines a menu options for display */
    displayOptions?: object|any[];
    /** Defines a menu options for popup */
    editorOptions?: object|any[]|Function;
    /** Defines a vue filter name */
    filter?: string|Function;
    /** Defines a column header action.  Same as [the `headerAction` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_actions.html). */
    headerAction?: object|string|Function;
    /** Defines a column header data field */
    headerField?: string;
    /** Defines a header icon */
    headerIcon?: object|string;
    /** Defines a column header style. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerStyle?: object|string|Function;
    /** Defines a column header type. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerType?: object|string|Function;
    /** Defines an icon. Same as [the `icon` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_icon.html). */
    icon?: object|string|Function;
    /** Defines a message generation method. Same as [the `message` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/cell_message.html). */
    message?: object|string|Function;
    /** Defines a menu options */
    options?: object|any[];
    /** Defines the layout rowspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    rowspan?: number|string;
    /** Defines a sort. See "[Sort by Column](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/column_sort.html)" for detail. */
    sort?: boolean|string|Function;
    onClickCell?: Function;
    onDblclickCell?: Function;
    onDbltapCell?: Function;
    onMousedownCell?: Function;
    onMouseupCell?: Function;
    onSelectedCell?: Function;
    onKeydown?: Function;
    onMousemoveCell?: Function;
    onMouseenterCell?: Function;
    onMouseleaveCell?: Function;
    onMouseoverCell?: Function;
    onMouseoutCell?: Function;
    onTouchstartCell?: Function;
    onContextmenuCell?: Function;
    onInputCell?: Function;
    onPasteCell?: Function;
    onDeleteCell?: Function;
    onEditableinputCell?: Function;
    onModifyStatusEditableinputCell?: Function;
    onResizeColumn?: Function;
    onScroll?: Function;
    onFocusGrid?: Function;
    onBlurGrid?: Function;
    onBeforeChangeValue?: Function;
    onChangedValue?: Function;
    onChangedHeaderValue?: Function;
    onRejectedPasteValues?: Function;
  },
  {
        /** Redraws the whole grid. */
    invalidate: () => void;
  },
  {
        /** Use this slot to set the header caption */
    "default"?: Slot<{} | undefined>;
  }
>;
/** Defines percent complete bar column. */
export const CGridPercentCompleteBarColumn: ComponentConstructor<
  {
        /** Defines a column data field */
    field?: object|string|Function;
    /** Defines a default column width */
    width?: number|string;
    /** Defines a column min width */
    minWidth?: number|string;
    /** Defines a column max width */
    maxWidth?: number|string;
    /** Defines a column style. Same as [the `style` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_styles/). */
    columnStyle?: object|string|Function;
    /** Defines an action */
    action?: object|string|Function;
    /** Defines a header caption */
    caption?: string|Function;
    /** Defines the layout colspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    colspan?: number|string;
    /** Defines a vue filter name */
    filter?: string|Function;
    /** Defines a formatter */
    formatter?: Function;
    /** Defines a column header action.  Same as [the `headerAction` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_actions.html). */
    headerAction?: object|string|Function;
    /** Defines a column header data field */
    headerField?: string;
    /** Defines a header icon */
    headerIcon?: object|string;
    /** Defines a column header style. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerStyle?: object|string|Function;
    /** Defines a column header type. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerType?: object|string|Function;
    /** Defines an icon. Same as [the `icon` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_icon.html). */
    icon?: object|string|Function;
    /** Defines a max value */
    max?: number|string;
    /** Defines a message generation method. Same as [the `message` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/cell_message.html). */
    message?: object|string|Function;
    /** Defines a min value */
    min?: number|string;
    /** Defines the layout rowspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    rowspan?: number|string;
    /** Defines a sort. See "[Sort by Column](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/column_sort.html)" for detail. */
    sort?: boolean|string|Function;
    onClickCell?: Function;
    onDblclickCell?: Function;
    onDbltapCell?: Function;
    onMousedownCell?: Function;
    onMouseupCell?: Function;
    onSelectedCell?: Function;
    onKeydown?: Function;
    onMousemoveCell?: Function;
    onMouseenterCell?: Function;
    onMouseleaveCell?: Function;
    onMouseoverCell?: Function;
    onMouseoutCell?: Function;
    onTouchstartCell?: Function;
    onContextmenuCell?: Function;
    onInputCell?: Function;
    onPasteCell?: Function;
    onDeleteCell?: Function;
    onEditableinputCell?: Function;
    onModifyStatusEditableinputCell?: Function;
    onResizeColumn?: Function;
    onScroll?: Function;
    onFocusGrid?: Function;
    onBlurGrid?: Function;
    onBeforeChangeValue?: Function;
    onChangedValue?: Function;
    onChangedHeaderValue?: Function;
    onRejectedPasteValues?: Function;
  },
  {
        /** Redraws the whole grid. */
    invalidate: () => void;
  },
  {
        /** Use this slot to set the header caption */
    "default"?: Slot<{} | undefined>;
  }
>;
/** Defines radio button column. */
export const CGridRadioColumn: ComponentConstructor<
  {
        /** Defines a column data field */
    field?: object|string|Function;
    /** Defines a default column width */
    width?: number|string;
    /** Defines a column min width */
    minWidth?: number|string;
    /** Defines a column max width */
    maxWidth?: number|string;
    /** Defines a column style. Same as [the `style` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_styles/). */
    columnStyle?: object|string|Function;
    /** Defines a header caption */
    caption?: string|Function;
    /** Defines disabled. You can also control each record by specifying a function. */
    disabled?: boolean|Function;
    /** Defines readonly. You can also control each record by specifying a function. */
    readonly?: boolean|Function;
    /** Change the check action from the default. */
    checkAction?: Function;
    /** Defines the layout colspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    colspan?: number|string;
    /** Defines a vue filter name */
    filter?: string|Function;
    /** Define a function that returns a radio group. */
    group?: Function;
    /** Defines a column header action.  Same as [the `headerAction` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_actions.html). */
    headerAction?: object|string|Function;
    /** Defines a column header data field */
    headerField?: string;
    /** Defines a header icon */
    headerIcon?: object|string;
    /** Defines a column header style. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerStyle?: object|string|Function;
    /** Defines a column header type. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerType?: object|string|Function;
    /** Defines an icon. Same as [the `icon` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_icon.html). */
    icon?: object|string|Function;
    /** Defines a message generation method. Same as [the `message` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/cell_message.html). */
    message?: object|string|Function;
    /** Defines the layout rowspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    rowspan?: number|string;
    /** Defines a sort. See "[Sort by Column](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/column_sort.html)" for detail. */
    sort?: boolean|string|Function;
    onClickCell?: Function;
    onDblclickCell?: Function;
    onDbltapCell?: Function;
    onMousedownCell?: Function;
    onMouseupCell?: Function;
    onSelectedCell?: Function;
    onKeydown?: Function;
    onMousemoveCell?: Function;
    onMouseenterCell?: Function;
    onMouseleaveCell?: Function;
    onMouseoverCell?: Function;
    onMouseoutCell?: Function;
    onTouchstartCell?: Function;
    onContextmenuCell?: Function;
    onInputCell?: Function;
    onPasteCell?: Function;
    onDeleteCell?: Function;
    onEditableinputCell?: Function;
    onModifyStatusEditableinputCell?: Function;
    onResizeColumn?: Function;
    onScroll?: Function;
    onFocusGrid?: Function;
    onBlurGrid?: Function;
    onBeforeChangeValue?: Function;
    onChangedValue?: Function;
    onChangedHeaderValue?: Function;
    onRejectedPasteValues?: Function;
  },
  {
        /** Redraws the whole grid. */
    invalidate: () => void;
  },
  {
        /** Use this slot to set the header caption */
    "default"?: Slot<{} | undefined>;
  }
>;
/** Defines tree column. */
export const CGridTreeColumn: ComponentConstructor<
  {
        /** Defines a column data field */
    field?: object|string|Function;
    /** Defines a default column width */
    width?: number|string;
    /** Defines a column min width */
    minWidth?: number|string;
    /** Defines a column max width */
    maxWidth?: number|string;
    /** Defines a column style. Same as [the `style` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_styles/). */
    columnStyle?: object|string|Function;
    /** Defines a header caption */
    caption?: string|Function;
    /** Defines disabled. You can also control each record by specifying a function. */
    disabled?: boolean|Function;
    /** Defines the layout colspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    colspan?: number|string;
    /** Defines a vue filter name */
    filter?: string|Function;
    /** Defines a column header action.  Same as [the `headerAction` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_actions.html). */
    headerAction?: object|string|Function;
    /** Defines a column header data field */
    headerField?: string;
    /** Defines a header icon */
    headerIcon?: object|string;
    /** Defines a column header style. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerStyle?: object|string|Function;
    /** Defines a column header type. Same as [the `headerStyle` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/header_styles.html) */
    headerType?: object|string|Function;
    /** Defines an icon. Same as [the `icon` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/column_icon.html). */
    icon?: object|string|Function;
    /** Defines a message generation method. Same as [the `message` property of the JS API](https://future-architect.github.io/cheetah-grid/documents/api/js/cell_message.html). */
    message?: object|string|Function;
    /** Defines the layout rowspan.
    This property can be used when defining in the `layout-header` and `layout-body` slots. */
    rowspan?: number|string;
    /** Defines a sort. See "[Sort by Column](https://future-architect.github.io/cheetah-grid/documents/api/js/advanced_header/column_sort.html)" for detail. */
    sort?: boolean|string|Function;
    onClickCell?: Function;
    onDblclickCell?: Function;
    onDbltapCell?: Function;
    onMousedownCell?: Function;
    onMouseupCell?: Function;
    onSelectedCell?: Function;
    onKeydown?: Function;
    onMousemoveCell?: Function;
    onMouseenterCell?: Function;
    onMouseleaveCell?: Function;
    onMouseoverCell?: Function;
    onMouseoutCell?: Function;
    onTouchstartCell?: Function;
    onContextmenuCell?: Function;
    onInputCell?: Function;
    onPasteCell?: Function;
    onDeleteCell?: Function;
    onEditableinputCell?: Function;
    onModifyStatusEditableinputCell?: Function;
    onResizeColumn?: Function;
    onScroll?: Function;
    onFocusGrid?: Function;
    onBlurGrid?: Function;
    onBeforeChangeValue?: Function;
    onChangedValue?: Function;
    onChangedHeaderValue?: Function;
    onRejectedPasteValues?: Function;
  },
  {
        /** Redraws the whole grid. */
    invalidate: () => void;
  },
  {
        /** Use this slot to set the header caption */
    "default"?: Slot<{} | undefined>;
  }
>;

declare module '@vue/runtime-core' {
  export interface GlobalComponents {
    /** Defines the Grid. */
    CGrid: typeof CGrid;
    "c-grid": typeof CGrid;
    /** Defines branch graph column. */
    CGridBranchGraphColumn: typeof CGridBranchGraphColumn;
    "c-grid-branch-graph-column": typeof CGridBranchGraphColumn;
    /** Defines button column. */
    CGridButtonColumn: typeof CGridButtonColumn;
    "c-grid-button-column": typeof CGridButtonColumn;
    /** Defines checkbox column. */
    CGridCheckColumn: typeof CGridCheckColumn;
    "c-grid-check-column": typeof CGridCheckColumn;
    /** Defines column. */
    CGridColumn: typeof CGridColumn;
    "c-grid-column": typeof CGridColumn;
    /** Defines multiple header.
    Can be used in the `default` slot of `CGrid`. */
    CGridColumnGroup: typeof CGridColumnGroup;
    "c-grid-column-group": typeof CGridColumnGroup;
    /** Defines layout header.
    Can be used in the `layout-header` slot of `CGrid`. */
    CGridHeader: typeof CGridHeader;
    "c-grid-header": typeof CGridHeader;
    /** Defines icon column. */
    CGridIconColumn: typeof CGridIconColumn;
    "c-grid-icon-column": typeof CGridIconColumn;
    /** Defines input column. */
    CGridInputColumn: typeof CGridInputColumn;
    "c-grid-input-column": typeof CGridInputColumn;
    /** Defines layout row.
    Can be used in the `layout-header` slot and the `layout-body` slot of `CGrid`. */
    CGridLayoutRow: typeof CGridLayoutRow;
    "c-grid-layout-row": typeof CGridLayoutRow;
    /** Defines link column. */
    CGridLinkColumn: typeof CGridLinkColumn;
    "c-grid-link-column": typeof CGridLinkColumn;
    /** Defines select menu column. */
    CGridMenuColumn: typeof CGridMenuColumn;
    "c-grid-menu-column": typeof CGridMenuColumn;
    /** Defines percent complete bar column. */
    CGridPercentCompleteBarColumn: typeof CGridPercentCompleteBarColumn;
    "c-grid-percent-complete-bar-column": typeof CGridPercentCompleteBarColumn;
    /** Defines radio button column. */
    CGridRadioColumn: typeof CGridRadioColumn;
    "c-grid-radio-column": typeof CGridRadioColumn;
    /** Defines tree column. */
    CGridTreeColumn: typeof CGridTreeColumn;
    "c-grid-tree-column": typeof CGridTreeColumn;
  }
}

export default CGrid;

export declare function install (Vue: any /* Vue 2 Vue object or Vue 3 App instance */): void;
